
Current release info
====================

.. image:: https://img.shields.io/pypi/v/statista
  :target: https://pypi.org/project/statista/0.1.2/


.. image:: https://img.shields.io/conda/v/conda-forge/hapi?label=conda-forge
  :target: https://pypi.org/project/statista/0.1.2/


.. image:: https://img.shields.io/pypi/pyversions/statista
  :target: https://pypi.org/project/statista/0.1.2/


.. image:: https://img.shields.io/github/forks/mafarrag/hapi?style=social   :alt: GitHub forks


.. image:: https://anaconda.org/conda-forge/hapi/badges/downloads.svg
  :target: https://anaconda.org/conda-forge/hapi


.. image:: https://img.shields.io/conda/vn/conda-forge/hapi   :alt: Conda (channel only)
  :target: https://pypi.org/project/statista/0.1.2/


.. image:: https://img.shields.io/gitter/room/mafarrag/Hapi
  :alt: Gitter


.. image:: https://static.pepy.tech/personalized-badge/statista?period=total&units=international_system&left_color=grey&right_color=blue&left_text=Downloads
  :target: https://pypi.org/project/statista/0.1.2/


.. image:: https://img.shields.io/pypi/v/statista
  :alt: PyPI


.. image:: https://anaconda.org/conda-forge/hapi/badges/platforms.svg
  :target: https://anaconda.org/conda-forge/hapi


.. image:: https://static.pepy.tech/personalized-badge/statista?period=total&units=international_system&left_color=grey&right_color=blue&left_text=Downloads
  :target: https://pepy.tech/project/statista



.. image:: https://static.pepy.tech/personalized-badge/statista?period=month&units=international_system&left_color=grey&right_color=blue&left_text=Downloads
  :target: https://pepy.tech/project/statista


.. image:: https://static.pepy.tech/personalized-badge/statista?period=week&units=international_system&left_color=grey&right_color=blue&left_text=Downloads
  :target: https://pepy.tech/project/statista




statista - statistics package
=====================================================================


**statista** is a statistics package.


Main Features
-------------
-
-

.. digraph:: Linking

    statista -> distributions;
    statista -> metrics;
    statista -> parameters;
    statista -> sensitivity;
    statista -> tools;
    dpi=200;

.. toctree::
   :hidden:
   :maxdepth: 1

   Installation <00Installation.rst>
   Tutorial <03tutorial.rst>
   GIS <05GIS.rst>
